import { SvelteComponentTyped } from "svelte";
import type { ImageProps as $$ImageProps } from '../Image.styles';
declare const __propDef: {
    props: {
        /** Override prop for custom theming the component's placeholder */ override?: $$ImageProps['override'];
        /** Predefined radius size from theme or number to set border-radius in px */ radius?: $$ImageProps['radius'];
        /** The image src to be used */ src?: $$ImageProps['src'];
        /** The width of the image that defaults to 100% */ width?: $$ImageProps['width'];
        /** The height of the image that defaults to the original image height adjusted to the width */ height?: $$ImageProps['height'];
    };
    events: {
        [evt: string]: CustomEvent<any>;
    };
    slots: {
        default: {};
    };
};
export declare type BackgroundImageProps = typeof __propDef.props;
export declare type BackgroundImageEvents = typeof __propDef.events;
export declare type BackgroundImageSlots = typeof __propDef.slots;
/**
 * BackgroundImage component can be used to add any content on image. It is useful for hero headers and other similar sections
 *
 * @see https://svelteui-docs.vercel.app/docs/core/image
 * @example
 *    ```svelte
 * 	<script>
 * 		const src = 'https://images.unsplash.com/photo-1649014048485-590f93c42936?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=987&q=80'
 * 	</script>
 *
 * 	<BackgroundImage radius="sm" {src}>
 * 		This content will be shown over the image
 * 	</BackgroundImage>
 *    ```
 *
 * It is suggested to wrap your component in a container element
 */
export default class BackgroundImage extends SvelteComponentTyped<BackgroundImageProps, BackgroundImageEvents, BackgroundImageSlots> {
}
export {};
