import { SvelteComponentTyped } from "svelte";
import type { ImageProps as $$ImageProps } from './Image.styles';
declare const __propDef: {
    props: {
        /** Override prop for custom theming the component's placeholder */ override?: $$ImageProps['override'];
        /** Override prop for custom theming the component's placeholder */ overridePlaceholder?: $$ImageProps['overridePlaceholder'];
        /** Predefined switch radius size */ radius?: $$ImageProps['radius'];
        class?: string;
        /** The image src to be used */ src?: $$ImageProps['src'];
        /** The image alt text, used as placeholder if the image is not loaded */ alt?: $$ImageProps['alt'];
        /** The object-fit option to be used by the image, defaults to 'cover' */ fit?: $$ImageProps['fit'];
        /** The width of the image that defaults to 100% */ width?: $$ImageProps['width'];
        /** The height of the image that defaults to the original image height adjusted to the width */ height?: $$ImageProps['height'];
        /** The caption of the image, will show below it if defined */ caption?: $$ImageProps['caption'];
        /** Defaults to a placeholder if the image has not yet loaded or an error occured */ usePlaceholder?: $$ImageProps['usePlaceholder'];
    };
    events: {
        [evt: string]: CustomEvent<any>;
    };
    slots: {
        placeholder: {};
    };
};
export declare type ImageProps = typeof __propDef.props;
export declare type ImageEvents = typeof __propDef.events;
export declare type ImageSlots = typeof __propDef.slots;
/**
 * Dynamic Image component with optional placeholder for loading and error state
 *
 * @see https://svelteui-docs.vercel.app/docs/core/image
 * @example
 * ```tsx
 * <Image src="https://images.unsplash.com/photo-1561046259-7d5b6e929ba0"/> // standard image
 * <Image src="https://images.unsplash.com/photo-1561046259-7d5b6e929ba0" alt="Doggo" width={100} caption="Very cool doggo" /> // standard image with width and caption
 * <Image src="" alt="Doggo" usePlaceholder /> // standard image that shows placeholder when it fails to load
 * ```
 */
export default class Image extends SvelteComponentTyped<ImageProps, ImageEvents, ImageSlots> {
}
export {};
